..  Copyright (C)  Brad Miller, David Ranum, Jeffrey Elkner, Peter Wentworth, Allen B. Downey, Chris
    Meyers, and Dario Mitchell.  Permission is granted to copy, distribute
    and/or modify this document under the terms of the GNU Free Documentation
    License, Version 1.3 or any later version published by the Free Software
    Foundation; with Invariant Sections being Forward, Prefaces, and
    Contributor List, no Front-Cover Texts, and no Back-Cover Texts.  A copy of
    the license is included in the section entitled "GNU Free Documentation
    License".

.. qnum::
   :prefix: tuples-6-
   :start: 1

Glossary
--------

.. glossary::


    tuple
        A type of sequence, much like a list but immutable. A tuple is created
        by enclosing one or more values in parentheses, separated by commas.

    packing
        When multiple values are specified, separated by commas, they are
        packed into a tuple.
        
    unpacking
        When a tuple is assigned to a collection of variable names separated
        by commas, the tuple is unpacked and the separate values are assigned to each 
        of the variables.
        
    pair
        A tuple with exactly two items.
